@@ -1,7 +1,7 @@
-from .base import CustomField
+from .number import NumberValidator
 from ..utils.validators import PositiveNumberValidator
 
 
-class CurrencyField(CustomField):
+class CurrencyField(NumberValidator):
     TYPE = "currency"
     VALIDATOR = PositiveNumberValidator
